If TRUE, only the estimates unequal to zero (estimates from the DIF-items)
are visualized with EffectStars.
...
further arguments for generic function effectstars.
References
Tutz, G. and Schauberger, G. (2015): A Penalty Approach to Differential Item Functioning in Rasch Models,
, Psychometrika, 80(1), 21 -- 43
Tutz, G. and Schauberger, G. (2013): Visualization of Categorical Response Models -
from Data Glyphs to Parameter Glyphs, Journal of Computational and Graphical Statistics 22(1), 156--177.
Gerhard Tutz (2012): Regression for Categorical Data, Cambridge University Press
# NOT RUN {### example for DIFlasso
library(DIFlasso)
data(simul.data)
Y <- simul.data[,1:10]
X <- simul.data[,11:13]
m1 <- DIFlasso(Y = Y, X = X, trace = TRUE)
effectstars(m1)
# }